Next.

- [X] script to add a task to a project's files
- [X] more explanation in the guide, including examples of all types of
      option, and the .whatnext file
- [X] a way for a file to self-exclude from summaries (vs .whatnext)
- [X] fix file-level `@after` being ignored when file has no headings
- [X] fix multiple warnings for one incorrect `@after`
- [X] ensure `@after` and deadlines that are quoted are ignored
- [X] add flag to skip \@after processing and show all outstanding tasks
